@@ -21,21 +21,22 @@
  *   Jim Luetgert 2010-03-11                                             *
  *************************************************************************/
 
+#include <errno.h>
+#include <fcntl.h>
+#include <math.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <fcntl.h>
-#include <math.h>
 #include <time.h>
-#include <errno.h>
-#include <signal.h>
-#include <earthworm.h>
-#include <kom.h>
-#include <transport.h>
-#include <imp_exp_gen.h>
-#include <mem_circ_queue.h>
-#include <priority_level.h>   /* for EW_PRIORITY definitions only */
-#include <socket_ew.h>
+
+#include "earthworm.h"
+#include "kom.h"
+#include "transport.h"
+#include "imp_exp_gen.h"
+#include "mem_circ_queue.h"
+#include "priority_level.h"   /* for EW_PRIORITY definitions only */
+#include "socket_ew.h"
 
 #include "nq2wws.h"
 
@@ -60,9 +61,9 @@ thr_ret MessageStacker( void * );    /* used to pass messages between main   */
 /* Other Thread things
  *********************/
 #define THREAD_STACK 8192
-static unsigned TidSocketSend;       /* SocketSender thread id                */
-static unsigned TidSocketRecv;       /* SocketRecv thread id                  */
-static unsigned TidStacker;          /* Thread moving messages from transport */
+static ew_thread_t TidSocketSend;       /* SocketSender thread id                */
+static ew_thread_t TidSocketRecv;       /* SocketRecv thread id                  */
+static ew_thread_t TidStacker;          /* Thread moving messages from transport */
                                      /*   to queue                            */
 /* Thread flags
  **************/
@@ -140,8 +141,6 @@ time_t now;                /* current time, used for timing heartbeats */
 time_t MyLastBeat;         /* time of last local (into Earthworm) hearbeat */
 int    ImportAlive   = 1;  /* switch for noting if our import is sending heart beats ok */
 
-extern int  errno;
-
 static    SHM_INFO  Region;       /* shared memory region to use for i/o    */
 
 char *Argv0;            /* pointer to executable name */
@@ -154,7 +153,7 @@ static char    MyModName[MAX_MOD_STR]; /* speak as this module name/id      */
 static int     LogSwitch;              /* 0 if no logfile should be written */
 static int     HeartBeatInt;           /* seconds between heartbeats        */
 static char    ServerIPAdr[16];        /* server's IP address               */
-static int     ServerPort;             /* Server's well-known port number   */
+static char    ServerPort[16];         /* Server's well-known port number   */
 static long    MaxMsgSize;             /* max size for input/output msgs    */
 static int     RingSize;               /* max messages in output circular buffer */
 static int     SendAliveInt;           /* Send alive messages this often    */
@@ -210,7 +209,7 @@ int   SendPacket     ( SEND_QUEUE *sq );
 int   WriteToSocket  ( int, char *, long, MSG_LOGO *, unsigned char );
 int   binEscape      ( char*, long , char* , long* , long );
 
-int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int*); 
+int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int*);
 int queue_putmsg( long recsize, char* trace_buffer);
 
 /**********************************************************************
@@ -226,18 +225,14 @@ int queue_putmsg( long recsize, char* trace_buffer);
 int main( int argc, char **argv )
 {
 /* Socket variables: */
-	int    on = 1;
 	int    clientLen;
-	char   client_ip[16];    /* IP address of client from inet_ntoa   */
-	struct sockaddr_in  skt;
-	struct sockaddr_in  client;
+	char   client_ip[64];    /* IP address of client from inet_ntoa   */
+	char   client_port[10];
+	struct sockaddr_storage  client;
 
 /* Other variables: */
-    char      whoami[50];
+	char      whoami[50];
 	time_t    timeNow;       /* current time                          */
-	int       res;
-	long      recsize;       /* size of retrieved message             */
-	MSG_LOGO  reclogo;       /* logo of retrieved message             */
 	int       AcceptTimeout; /* time in milliseconds for accept_ew()  */
 	int       sockErr;
 	char     *ptr;           /* temp pointer for setting up SendQueue */
@@ -300,7 +295,7 @@ int main( int argc, char **argv )
 /* Do a sanity check on the SocketTimeoutLength.
    If it is -1 (no timeout; block on the call) then
    leave it alone. */
-   
+
    if( SocketTimeoutLength != -1 &&
        1000*(RcvAliveInt)  >= SocketTimeoutLength )
    {
@@ -413,58 +408,14 @@ int main( int argc, char **argv )
  *******************************/
    SocketSysInit();
 
-   if( ( PassiveSocket = socket_ew( PF_INET, SOCK_STREAM, 0) ) == -1 )
+   if( ( PassiveSocket = setuptcpserver_ew(ServerIPAdr, ServerPort, 0) ) < 0)
    {
-      logit( "et", "%s Error opening socket; exiting!\n", whoami );
+      logit( "et", "%s Error setting up TCP server socket; exiting!\n", whoami );
       tport_detach( &Region );
       return( -1 );
    }
    SocketStatus = SOCK_NEW;
 
-/* Fill in server's socket address structure
- ********************************************/
-   memset( (char *) &skt, '\0', sizeof(skt) );
-   skt.sin_family = AF_INET;
-   skt.sin_port   = htons( (short)ServerPort );
-#if defined(_LINUX) || defined(_MACOSX)
-   if ((int)(skt.sin_addr.s_addr = inet_addr(ServerIPAdr)) == -1)
-#else
-   if ((int)(skt.sin_addr.S_un.S_addr = inet_addr(ServerIPAdr)) == -1)
-#endif
-   {
-      logit( "e", "%s inet_addr failed for ServerIPAdr <%s>;"
-            " exiting!\n", whoami, ServerIPAdr );
-      return( -1 );
-   }
-
-/* Allows the server to be stopped and restarted
- ************************************************/
-   on=1;
-   if( setsockopt( PassiveSocket, SOL_SOCKET, SO_REUSEADDR,
-                  (char *)&on, sizeof(char *) ) != 0 )
-   {
-      logit( "et", "%s Error on setsockopt; exiting!\n", whoami );
-      perror("Export setsockopt");
-      export_shutdown( -1 );
-   }
-
-/* Bind socket to a name
- ************************/
-   if ( bind_ew( PassiveSocket, (struct sockaddr *) &skt, sizeof(skt)) )
-   {
-      logit("et", "%s error binding socket; exiting.\n", whoami );
-      perror("Export bind error");
-      export_shutdown( -1 );
-   }
-
-/* Prepare for connect requests
- *******************************/
-   if( listen_ew( PassiveSocket, 0 ) )
-   {
-      logit("et", "%s socket listen error; exiting!\n", whoami );
-      export_shutdown( 1 );
-   }
-
 /* Accept a connection (blocking)
  *********************************/
    clientLen = sizeof( client );
@@ -500,7 +451,7 @@ int main( int argc, char **argv )
       time(&MyLastBeat);
    }
 
-   strcpy( client_ip, inet_ntoa(client.sin_addr) );
+   formatsocketaddress_ew((struct sockaddr *) &client, clientLen, client_ip, client_port);
 	LiveConnection = 1; /*970623:ldd*/
    if( SocketStatus == SOCK_NOT_CONN )
    { /* we cried before, so now we have to let them know we're OK */
@@ -584,7 +535,7 @@ int main( int argc, char **argv )
       {
          logit("et", "%s restarting. This procedure may hang. "
                "Make sure restartMe is set in my .desc file\n", whoami  );
-               
+
       /* The code below occasionally hangs before the "waiting for new connection"
        * statement. The solution is to set the "restartMe" option in the .desc
        * file, which will cause me to be restarted by statmgr/startstop. */
@@ -592,7 +543,7 @@ int main( int argc, char **argv )
        * by the threads being killed. If a thread holds a mutex when it is killed,
        * the mutex is held forever. It would be better to use thread cancellation
        * once earthworm is free from Solaris threads. PNL, 1/10/00 */
-       
+
          closesocket_ew( ActiveSocket,  SOCKET_CLOSE_IMMEDIATELY_EW );
          closesocket_ew( PassiveSocket, SOCKET_CLOSE_IMMEDIATELY_EW );
          SocketStatus = SOCK_CLOSED;
@@ -678,7 +629,6 @@ shutdown:
 }
 /*************************** end of main **************************/
 
-
 /**********************************************************************
  *                          SocketRecv()                              *
  * Read socket for client heartbeats and set global variable showing  *
@@ -691,7 +641,7 @@ shutdown:
 
 thr_ret SocketRecv( void *dummy )
 {
-    char        whoami[50];
+	char        whoami[50];
 	static int  state;
 	static char chr;
 	static int  nr;                 /* total #chars in inBuffer     */
@@ -700,7 +650,7 @@ thr_ret SocketRecv( void *dummy )
 	static char startCharacter=STX; /* ASCII STX characer  */
 	static char endCharacter  =ETX; /* ASCII ETX character */
 
-    sprintf(whoami, "%s: %s: ", progname, "SocketRecv");
+	sprintf(whoami, "%s: %s: ", progname, "SocketRecv");
 	
 	SocketRecvStatus = THREAD_ALIVE;
 
@@ -852,9 +802,9 @@ thr_ret SocketRecv( void *dummy )
          }
       } /* end of state==ASSEMBLING_MESSAGE processing */
    }  /* end while of loop over characters in inBuffer */
+   return THR_NULL_RET;
 }  /* end of SocketRecv thread */
 
-
 /************************** SocketSender ******************************
  * Pull a messsage from the queue, and push it out the socket with a  *
  * known sequence number.                                             *
@@ -875,7 +825,7 @@ thr_ret SocketSender( void *dummy )
 	int         nresent = 0;
 
 	sprintf(whoami, "%s: %s: ", progname, "SocketSender");
-    
+
 /* Tell the main thread we're ok; initialize stuff
  **************************************************/
 	SocketSenderStatus = THREAD_ALIVE;
@@ -918,7 +868,7 @@ thr_ret SocketSender( void *dummy )
    if(nresent) logit("et", "%s Re-sent %d non-ACKed msgs from SendQueue.\n",
                       whoami, nresent );
    else        logit("et", "%s SendQueue was all ACKed; no msgs re-sent.\n",
-                      whoami, nresent );
+                      whoami );
 
 /*----------------------- main SocketSender loop ------------------------*/
 
@@ -982,7 +932,7 @@ thr_ret SocketSender( void *dummy )
       sq->sequence = SendSequence;
       SendSequence = (SendSequence+1)%SendQueueLen;
 /*      if(Verbose) exportfilter_logmsg( sq->msg, sq->msglen, sq->logo.type,
-                                      "dequeued:       " ); 
+                                      "dequeued:       " );
  */
    /* Send the just-dequeued message
     ********************************/
@@ -996,6 +946,7 @@ thr_ret SocketSender( void *dummy )
                                       "sent2socket:    " );
  */
    } /* End of SocketSender while(1) loop */
+   return THR_NULL_RET;
 }
 
 /******************************************************************
@@ -1029,7 +980,6 @@ int SendPacket( SEND_QUEUE *sq )
    return( 0 );
 }
 
-
 /***************************binEscape******************************
  *    make a binary message safe for shipping: insert an escape   *
  *    character before any bit pattern which looks like a sacred  *
@@ -1070,7 +1020,6 @@ int binEscape( char* inmsg, long inSize,
    return(0);
 }
 
-
 /*************************** WriteToSocket ************************
  *    send a message logo and message to the socket               *
  *    returns  0 if there are no errors                           *
@@ -1088,7 +1037,7 @@ int WriteToSocket( int ActiveSocket, char *msg, long msglength,
 	char    whoami[50];
 
     sprintf(whoami, "%s: %s: ", progname, "WriteToSocket");
-    
+
 /* Send "start of transmission" flag, sequence#, ascii logo
  **********************************************************/
    sprintf( asciilogo, "%cSQ:%3d%3d%3d%3d", startmsg, (int) seq,
@@ -1124,17 +1073,12 @@ int WriteToSocket( int ActiveSocket, char *msg, long msglength,
    return( 0 );
 }
 
-
 /********************** Message Stacking Thread *******************
 *          Move messages from mSEED files to memory queue         *
 ******************************************************************/
 thr_ret MessageStacker( void *dummy )
 {
-	long       recsize;	/* size of retrieved message             */
-	MSG_LOGO   reclogo;       /* logo of retrieved message             */
-	int        i, res, ret;
-	int        NumOfTimesQueueLapped= 0; /* number of messages lost due to queue lap */
-	int        NumOfElementsInQueue; /* number of messages in the queue  */
+	int        i;
 	int        NumOfTBufs; /* number of tracebufs burst from this file  */
 	int        NumOfseeds; /* number of mSEED records burst from this file  */
 
@@ -1146,14 +1090,13 @@ thr_ret MessageStacker( void *dummy )
     int     FileOK, rc;
     DATA_HDR    mseed_hdr, *mseed_hdr_ptr;
     int         max_num_points, msdata[20000];
-	unsigned char alert, okay;			/* flags */
+	unsigned char okay;			/* flags */
 	time_t stime, etime;	
 	clock_t start;
-	double  secs, tics;	   
-	SEND_QUEUE *sq;   /* working pointer into SendQueue   */
+	double  secs, tics;
 
     sprintf(whoami, "%s: %s: ", progname, "MessageStacker");
-    
+
     /* Change working directory to "NQFilesInDir" - where the files should be
      ************************************************************************/
 	if ( chdir_ew( NQFilesInDir ) == -1 ) {
@@ -1163,7 +1106,6 @@ thr_ret MessageStacker( void *dummy )
 	if(Debug) logit( "e", "%sChanged working directory to %s\n ", whoami, NQFilesInDir );
 	okay = 1;
 
-	
    /* Make sure the queue starts off empty
    **************************************
 	do {
@@ -1181,7 +1123,7 @@ thr_ret MessageStacker( void *dummy )
 
 	    /* Start of working loop over files.
 	    ************************************/
-	    while ((GetFileName (fname)) != 1 && okay) {    
+	    while ((GetFileName (fname)) != 1 && okay) {
 			time(&stime);
 			start = clock();
 	        /* Open the file for reading only.  Since the file name
@@ -1229,24 +1171,24 @@ thr_ret MessageStacker( void *dummy )
 	        while ((rc=read_ms (&mseed_hdr_ptr,  msdata, max_num_points, fp )) != EOF) {
 	            if(rc >= 0) {
 					if(Debug) {
-						logit("e", "\nrc: %d seq_no: %d S_C_N_L: %s_%s_%s_%s  nsamp: %d %d %d %c\n", 
-								rc, mseed_hdr_ptr->seq_no, mseed_hdr_ptr->station_id, mseed_hdr_ptr->channel_id, 
-								mseed_hdr_ptr->network_id, mseed_hdr_ptr->location_id, mseed_hdr_ptr->num_samples, 
+						logit("e", "\nrc: %d seq_no: %d S_C_N_L: %s_%s_%s_%s  nsamp: %d %d %d %c\n",
+								rc, mseed_hdr_ptr->seq_no, mseed_hdr_ptr->station_id, mseed_hdr_ptr->channel_id,
+								mseed_hdr_ptr->network_id, mseed_hdr_ptr->location_id, mseed_hdr_ptr->num_samples,
 								mseed_hdr_ptr->sample_rate, mseed_hdr_ptr->data_type, mseed_hdr_ptr->record_type );
 	                }
 					if (rc == 0) continue;	/* No data in record */
-	                
+
 					if(mseed_to_tbuf(msdata, mseed_hdr_ptr, 1000, &NumOfTBufs) == 0) {
 					
 					}
-	                
+
 	            }
 	            else {
 					strcpy(errbuf, " ");
 					if(rc == -2) strcpy(errbuf, "(MiniSEED error)");
 					if(rc == -3) strcpy(errbuf, "(Malloc error)");
 					if(rc == -4) strcpy(errbuf, "(Time error)");
-					logit("e", "\n *** Error Processing file %s, Error: %d %s ***\n", 
+					logit("e", "\n *** Error Processing file %s, Error: %d %s ***\n",
 										fname, rc, errbuf);
 					FileOK = FALSE;
 					if(rc < -1) break;
@@ -1257,11 +1199,10 @@ thr_ret MessageStacker( void *dummy )
 	            	logit( "et", " %s taking a break.\n", fname);
 					sleep_ew(2000);
 	            }  */
-	        } 
+	        }
 
-	        
 	        fclose (fp);
-	        
+
 	        /* Dispose of file
 	        *********************/
 	        if (FileOK) {
@@ -1283,11 +1224,11 @@ thr_ret MessageStacker( void *dummy )
 	            if (rename (fname, outFname) != 0 ) {
 	                logit( "e", "Fatal: Error moving %s: %s\n", fname, strerror(errno));
 	                goto error;
-	            } 
+	            }
 	            if(Debug) logit( "e", "Moved %s to %s\n", fname, NQFilesErrorDir);
 	            continue;
 	        }
-	        
+
 			time(&etime);
 			tics = (double)(clock() - start);
 			secs = tics / (double)CLOCKS_PER_SEC;
@@ -1297,12 +1238,9 @@ thr_ret MessageStacker( void *dummy )
 						fname, difftime(etime,stime), NumOfTBufs);
 			sleep_ew(100);
 		}
-	        
-	    
+
 		sleep_ew(2000);
 
-
-
 	} /* end of while */
 
 	/* we're quitting
@@ -1311,9 +1249,9 @@ error:
 	MessageStackerStatus = THREAD_ERR; /* file a complaint to the main thread */
 	KillSelfThread(); /* main thread will restart us */
 	MessageStackerAlive = THREAD_ERR; /* Assume the kill worked. */
+	return THR_NULL_RET;
 }
 
-
 /********************************************************************
  *  mseed_to_tbuf converts MiniSEED to TraceBuf2 and                *
  *  writes to queue with tracebufs starting on integer seconds.     *
@@ -1321,7 +1259,7 @@ error:
 
 static TracePacket trace_buffer;
 
-int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufcount) 
+int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufcount)
 {
     char            whoami[50];
     TRACE2_HEADER  *trace2_hdr;		/* ew trace header */
@@ -1329,12 +1267,11 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
     int*            inpTracePtr;
     char*           myTracePtr;
     char            sncl[20];
-	int             NumOfElementsInQueue; /* number of messages in the queue  */
 
     sprintf(whoami, "%s: %s: ", progname, "mseed_to_tbuf");
 
 	/*** If we have a log channel, return! ***/
-	if (mseed_hdr->sample_rate == 0 || 
+	if (mseed_hdr->sample_rate == 0 ||
 	    mseed_hdr->sample_rate_mult == 0 ||
 	    mseed_hdr->num_samples == 0)  {
 		return 1;
@@ -1365,7 +1302,7 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 	}
 	
 	if(k == -1) {
-		/*** New channel. Start floating buffer at next integer second. ***/ 
+		/*** New channel. Start floating buffer at next integer second. ***/
 		if(nchans>=MAXCHANS) {
 			logit("et", "%s Error - Too many channels in this mSEED file. Only %d allowed. Data for %s ignored.\n", whoami, MAXCHANS, sncl);
 			return 1;
@@ -1378,7 +1315,7 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		chanbuf[k].starttime = (double)unix_time_from_int_time(mseed_hdr->begtime) + 1;
 		chanbuf[k].endtime   = chanbuf[k].starttime + (double)(trace2_hdr->nsamp - 1)/trace2_hdr->samprate;
 		chanbuf[k].endtime   = chanbuf[k].endtime - 1;
-		if(Debug) logit("et", "%sk: %d offset: %d numsamps: %d %s_%s_%s_%s\n", whoami, k, offset, mseed_hdr->num_samples, trace2_hdr->sta,trace2_hdr->net,trace2_hdr->chan,trace2_hdr->loc); 
+		if(Debug) logit("et", "%sk: %d offset: %d numsamps: %d %s_%s_%s_%s\n", whoami, k, offset, mseed_hdr->num_samples, trace2_hdr->sta,trace2_hdr->net,trace2_hdr->chan,trace2_hdr->loc);
 	} else {
 		for(i=0,j=chanbuf[k].bufptr;i<mseed_hdr->num_samples;i++,j++) chanbuf[k].buf[j] = bytes[i];
 		chanbuf[k].bufptr = j;
@@ -1390,8 +1327,8 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		trace2_hdr->endtime = (double)unix_time_from_int_time(mseed_hdr->endtime) +
 					((double)(mseed_hdr->endtime.usec)/USECS_PER_SEC);
 		logit("et", "%sRcvd from mSEED   %s_%s_%s_%s %d Time: %f  %f \n",  whoami,
-				trace2_hdr->sta, trace2_hdr->chan, trace2_hdr->net, trace2_hdr->loc, 
-				mseed_hdr->num_samples, 
+				trace2_hdr->sta, trace2_hdr->chan, trace2_hdr->net, trace2_hdr->loc,
+				mseed_hdr->num_samples,
 				trace2_hdr->starttime, trace2_hdr->endtime);
 	}
 	
@@ -1403,8 +1340,8 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		chanbuf[k].endtime    = chanbuf[k].starttime + (double)(trace2_hdr->nsamp - 1)/trace2_hdr->samprate;
 		trace2_hdr->endtime   = chanbuf[k].endtime;
 
-		myTracePtr = &trace_buffer.msg[0] + sizeof(TRACE2_HEADER);        
-		inpTracePtr = &chanbuf[k].buf[0];        
+		myTracePtr = &trace_buffer.msg[0] + sizeof(TRACE2_HEADER);
+		inpTracePtr = &chanbuf[k].buf[0];
 	
 		/* Move the trace */
 		memcpy( (void*)myTracePtr, (void*)inpTracePtr, trace2_hdr->nsamp*sizeof(int32_t) );
@@ -1412,15 +1349,15 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		out_message_size = sizeof(TRACE2_HEADER)+sizeof(int)*trace2_hdr->nsamp;
 		
 		if(out_message_size>=MaxMsgSize) {
-			logit("et", "%s Error - out_message_size (%d) >= MaxMsgSize (%d)\n", whoami, out_message_size, MaxMsgSize);
+			logit("et", "%s Error - out_message_size (%d) >= MaxMsgSize (%ld)\n", whoami, out_message_size, MaxMsgSize);
 			out_message_size = MaxMsgSize;
 		}
 		
 		if(Debug) {
-			logit("et", "%sSENT to EARTHWORM %s_%s_%s_%s %d Time: %f  %f %f %f %d %d %d\n", whoami, 
-					trace2_hdr->sta, trace2_hdr->chan, 
-					trace2_hdr->net, trace2_hdr->loc, trace2_hdr->nsamp, 
-					trace2_hdr->starttime, trace2_hdr->endtime, trace2_hdr->endtime-trace2_hdr->starttime, 
+			logit("et", "%sSENT to EARTHWORM %s_%s_%s_%s %d Time: %f  %f %f %f %d %d %d\n", whoami,
+					trace2_hdr->sta, trace2_hdr->chan,
+					trace2_hdr->net, trace2_hdr->loc, trace2_hdr->nsamp,
+					trace2_hdr->starttime, trace2_hdr->endtime, trace2_hdr->endtime-trace2_hdr->starttime,
 					trace2_hdr->starttime-endtime, out_message_size, chanbuf[k].bufptr, j-i);
 		}
 		/* transport it off to the queue */
@@ -1431,8 +1368,8 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		} else {
 			*tbufcount = *tbufcount + 1;
 			if ( Verbose==TRUE ) {
-				fprintf(stderr, "SENT to EARTHWORM %s_%s_%s_%s %d Time: \n", 
-						trace2_hdr->sta, trace2_hdr->chan, 
+				fprintf(stderr, "SENT to EARTHWORM %s_%s_%s_%s %d Time: \n",
+						trace2_hdr->sta, trace2_hdr->chan,
 						trace2_hdr->net, trace2_hdr->loc, trace2_hdr->nsamp);
 			}
 		}
@@ -1442,9 +1379,9 @@ int mseed_to_tbuf(int *bytes, DATA_HDR *mseed_hdr, int out_data_size, int *tbufc
 		chanbuf[k].bufptr -= trace2_hdr->nsamp;
 		chanbuf[k].starttime += 1;
     }
-             
+
 	return 0;
-} 
+}
 
 /******************************************************************
 *          Move tracebufs from mSEED files to memory queue        *
@@ -1453,7 +1390,7 @@ int queue_putmsg( long recsize, char* trace_buffer)
 {
     char      whoami[50];
 	MSG_LOGO  reclogo;                  /* logo of retrieved message             */
-	int		  res, ret, sleep, min;
+	int       ret, sleep, min;
 	int       NumOfTimesQueueLapped= 0; /* number of messages lost due to queue lap */
 	int       NumOfElementsInQueue;     /* number of messages in the queue  */
 
@@ -1462,7 +1399,7 @@ int queue_putmsg( long recsize, char* trace_buffer)
 	RequestMutex();
 	NumOfElementsInQueue = getNumOfElementsInQueue(&OutQueue);
 	ReleaseMutex_ew();
-	if(Debug) logit("et", "%sQueue has %d elements.  \n", whoami, NumOfElementsInQueue); 
+	if(Debug) logit("et", "%sQueue has %d elements.  \n", whoami, NumOfElementsInQueue);
 	while(NumOfElementsInQueue > RingSize-10) {
 		if(++sleep > 120) {
 			logit("et", "%sQueue may be stalled.  \n", whoami);
@@ -1473,10 +1410,10 @@ int queue_putmsg( long recsize, char* trace_buffer)
 		MessageStackerAlive = THREAD_ALIVE;
 		RequestMutex();
 		NumOfElementsInQueue = getNumOfElementsInQueue(&OutQueue);
-		if(Debug) logit("et", "Queue has %d elements.  %d\n", NumOfElementsInQueue, sleep); 
+		if(Debug) logit("et", "Queue has %d elements.  %d\n", NumOfElementsInQueue, sleep);
 		ReleaseMutex_ew();
 	}
-	if(sleep > 0) logit("et", "Queue was filled. Slept %d minutes %d sec.  \n", min/2, sleep); 
+	if(sleep > 0) logit("et", "Queue was filled. Slept %d minutes %d sec.  \n", min/2, sleep);
 
 	/* Process retrieved msg (res==GET_OK,GET_MISS,GET_NOTRACK)
 	***********************************************************/
@@ -1526,13 +1463,13 @@ int queue_putmsg( long recsize, char* trace_buffer)
 error:
    MessageStackerStatus = THREAD_ERR; /* file a complaint to the main thread */
    KillSelfThread(); /* main thread will restart us */
-	MessageStackerAlive = THREAD_ERR; /* Assume the kill worked. */
+   MessageStackerAlive = THREAD_ERR; /* Assume the kill worked. */
+   return -1;
 }
 
-
 /*****************************************************************************
  *  export_config() processes command file(s) using kom.c functions;         *
- *                    exits if any errors are encountered.               *
+ *                    exits if any errors are encountered.                   *
  *****************************************************************************/
 void export_config( char *configfile )
 {
@@ -1630,7 +1567,7 @@ void export_config( char *configfile )
       /* Well-known server port number
        *******************************/
 /*5*/    else if( k_its("ServerPort") ) {
-            ServerPort = k_int();
+            strncpy( ServerPort, str, sizeof( ServerPort ));
             init[5] = 1;
          }
 
@@ -1682,7 +1619,7 @@ void export_config( char *configfile )
                init[11]=1;
             }
          }
-     
+
       /* Input directory containing mSEED files
        ****************************************/
 /*12*/	else if( k_its("NQFilesInDir") ) {
@@ -1690,7 +1627,7 @@ void export_config( char *configfile )
 			if(str) strcpy( NQFilesInDir, str );
 			init[12] = 1;
 		}
-     
+
       /* Output directory for processed mSEED files
        ********************************************/
 /*13*/	else if( k_its("NQFilesOutDir") ) {
@@ -1698,7 +1635,7 @@ void export_config( char *configfile )
 			if(str) strcpy( NQFilesOutDir, str );
 			init[13] = 1;
 		}
-     
+
       /* Output directory for problem mSEED files
        ******************************************/
 /*14*/	else if( k_its("NQFilesErrorDir") ) {
@@ -1714,7 +1651,7 @@ void export_config( char *configfile )
 			Debug = 1;
 			/* turn on the LogFile too! */
 			LogSwitch = 1;
-		 }  
+		 }
 
 
       /* Optional: Reset length of Send Queue
@@ -1745,7 +1682,7 @@ void export_config( char *configfile )
             SOCKET_ewDebug = k_int();
          }
 
-		/* Optional cmd: Turn on heartbeat logging 
+		/* Optional cmd: Turn on heartbeat logging
 		********************************************************/
 		else if( k_its("HBDebug") ) {
 			HBflag = k_int();
@@ -1855,7 +1792,7 @@ void export_lookup( void )
 		logit( "e",
               "%s: Message type <TYPE_TRACEBUF2> not found in earthworm_global.d; exiting!\n", progname);
         exit(-1);
-   } 
+   }
    return;
 }
 
@@ -1879,10 +1816,10 @@ void export_status( unsigned char type, short ierr, char *note )
    time( &t );
 
    if( type == TypeHeartBeat )
-      sprintf( msg, "%ld %ld\n\0", (long) t, (long) MyPid);
+      sprintf( msg, "%ld %ld\n", (long) t, (long) MyPid);
    else if( type == TypeError )
    {
-      sprintf( msg, "%ld %hd %s\n\0", (long) t, ierr, note);
+      sprintf( msg, "%ld %hd %s\n", (long) t, ierr, note);
       logit( "et", "%s(%s): %s\n", Argv0, MyModName, note );
    }
    size = strlen( msg );   /* don't include the null byte in the message */
