@@ -27,24 +27,25 @@
 
 #define VERSION "0.0.12 2016.05.31"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #ifdef _WINNT
 #include <io.h>
 #else
 #include <dirent.h>
 #endif
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <time.h>
-#include <earthworm.h>
-#include <kom.h>
-#include <transport.h>
-#include <rw_mag.h>
-#include <read_arc.h>
-#include <chron3.h>
-#include <fleng.h>
 
-#include <nordic.h>
+#include "earthworm.h"
+#include "kom.h"
+#include "transport.h"
+#include "rw_mag.h"
+#include "read_arc.h"
+#include "chron3.h"
+#include "fleng.h"
+
+#include "nordic.h"
 
 #define MAX_EVENTS             5       /* Number of events for which details are remembered */
 #define FILE_NAME_LEN        150       /* Number of chars in name of sfiles */
@@ -195,7 +196,7 @@ int main( int argc, char **argv )
 	/* Attach to Input/Output shared memory ring
 	 *******************************************/
 	tport_attach( &Region, RingKey );
-	logit( "", "seisan_report: Attached to public memory region %s: %d\n", RingName, RingKey );
+	logit( "", "seisan_report: Attached to public memory region %s: %ld\n", RingName, RingKey );
 
 	/* Force a heartbeat to be issued in first pass thru main loop
 	 *************************************************************/
@@ -317,7 +318,7 @@ void seisan_report_hinvarc( char *arcmsg )
 		if( event[event_index].arc.num_phases > 0 ) free_phases( &event[event_index].arc );
 		return;
 	}
-	logit( "t", "parsed event %ld\n", event[event_index].qid );
+	logit( "t", "parsed event %s\n", event[event_index].qid );
 	
 	/* Put QID in structure separately */
 	sprintf( event[event_index].qid, "%ld", event[event_index].arc.sum.qid );
@@ -1090,5 +1091,3 @@ void seisan_report_status( unsigned char type, short ierr, char *note )
 	}
 	return;
 }
-
-
