@@ -1,3 +1,3 @@
 
-void log( char *flag, char *format, ... );
+void log_msg( char *flag, char *format, ... );
 void log_init( char *LogName, char *tz, int bufSize, int logflag );
