@@ -3,9 +3,6 @@
 #include "k2pktdef.h"
 #include "trace_buf.h"
 
-
-#define K2INFO_TYPE_STRING "TYPE_K2INFO_PACKET"
-
 typedef struct {
         char    net[TRACE2_NET_LEN];     /* Network name */
         char    sta[TRACE2_STA_LEN];     /* Site name */
@@ -27,9 +24,15 @@ typedef union {
 	K2INFO_HEADER k2info;
 } K2infoPacket;  
 
+typedef struct {
+        char    net[TRACE2_NET_LEN];     /* Network name */
+        char    sta[TRACE2_STA_LEN];     /* Site name */
+} K2SNW;
 
-/* FUNCTIONS: only 2 */
+
+/* FUNCTIONS */
 int k2info_init();
+int k2snw_init();
 void k2info_send(int data_type, char *item);
 void k2snw_send(char *param_value_msg);
 
