@@ -7,7 +7,7 @@
  * 	Istituto Nazionale di Geofisica e Vulcanologia - Italy
  *	quintiliani@ingv.it
  *
- * $Id: nmxptool_getoptlong.c 4965 2012-07-22 07:12:34Z quintiliani $
+ * $Id: nmxptool_getoptlong.c 6894 2017-01-04 11:40:00Z quintiliani $
  *
  */
 
@@ -17,6 +17,7 @@
 
 #include <errno.h>
 #include <unistd.h>
+#include <limits.h>
 
 #include "config.h"
 #include "nmxp.h"
@@ -107,7 +108,7 @@ void nmxptool_supports() {
 #endif
 
     nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY, ", SeedLink ");
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
     nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY, "YES");
 #else
     nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY, "NO");
@@ -179,7 +180,7 @@ NMXP_LOG_STR(DAP_VERSION)
 \n", NMXP_LOG_STR(PACKAGE_NAME));
 #endif
 
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
     nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY, "\
        %s <option ... option> [ -k  |  -K ]\n\
              Launched as SeedLink plug-in to feed the SL-Server.\n\
@@ -362,7 +363,7 @@ Mini-SEED arguments:\n");
 #endif
 
 
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
     nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY, "\
 SeedLink arguments:\n");
 
@@ -599,6 +600,42 @@ int nmxptool_read_time(char *str_input, int32_t *pvalue) {
     return ret_errors;
 }
 
+
+int nmxptool_parse_long(const char *str, long *val)
+{
+	char *temp;
+	int rc = 1;
+	errno = 0;
+	*val = strtol(str, &temp, 0);
+
+	if (temp == str || *temp != '\0' ||
+			( (*val == LONG_MIN || *val == LONG_MAX) && errno == ERANGE)
+	   ) {
+		rc = 0;
+	}
+
+	return rc;
+}
+
+int nmxptool_parse_int(const char *str, int *val)
+{
+	long v = 0;
+	int rc = 1;
+
+	rc = nmxptool_parse_long(str, &v);
+
+	if(rc) {
+		if(v >= INT_MIN && v <= INT_MAX) {
+			*val = v;
+		} else {
+			rc = 0;
+		}
+	}
+
+	return rc;
+}
+
+
 int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 {
     int ret_errors = 0;
@@ -664,15 +701,15 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 	{"reclen",       required_argument, NULL, 'r'},
 #endif
 	{"writefile",    no_argument,       NULL, 'w'},
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
 	{"slink",        required_argument, NULL, 'k'},
 #endif
 #ifdef HAVE_LIBMSEED
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
 	{"slinkms",      required_argument, NULL, 'K'},
 #endif
 #endif
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
 	{"timing_quality", required_argument, NULL, 'Q'},
 #endif
 #ifndef HAVE_WINDOWS_H
@@ -699,13 +736,13 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 #endif
 
 
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
     strcat(optstr, "Q:");
     strcat(optstr, "k:");
 #endif
 
 #ifdef HAVE_LIBMSEED
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
     strcat(optstr, "K:");
 #endif
 #endif
@@ -766,11 +803,17 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 		    break;
 
 		case 'P':
-		    params->portnumberpds = atoi(optarg);
+			if(nmxptool_parse_int(optarg, &(params->portnumberpds)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing NaqsServer port number '%s'.\n", optarg);
+				ret_errors++;
+			}
 		    break;
 
 		case 'D':
-		    params->portnumberdap = atoi(optarg);
+			if(nmxptool_parse_int(optarg, &(params->portnumberdap)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing DataServer port number '%s'.\n", optarg);
+				ret_errors++;
+			}
 		    break;
 
 		case 'C':
@@ -792,15 +835,22 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 		    break;
 
 		case 'S':
-		    params->stc = atoi(optarg);
-		    nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Short-Term-Completion %d.\n", params->stc);
-		    if(params->stc >= 0) {
-			params->rate = 0; // original sample rate
-		    }
+			if(nmxptool_parse_int(optarg, &(params->stc)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing Short-Term-Completion '%s'.\n", optarg);
+				ret_errors++;
+			} else {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Short-Term-Completion %d.\n", params->stc);
+				if(params->stc >= 0) {
+					params->rate = 0; // original sample rate
+				}
+			}
 		    break;
 
 		case 'R':
-		    params->rate = atoi(optarg);
+			if(nmxptool_parse_int(optarg, &(params->rate)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing Rate '%s'.\n", optarg);
+				ret_errors++;
+			}
 		    break;
 
 		case 's':
@@ -842,19 +892,30 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 		    break;
 
 		case 'M':
-		    params->max_tolerable_latency = atoi(optarg);
-		    nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Max_tolerable_latency %d\n",
-			    params->max_tolerable_latency);
+			if(nmxptool_parse_int(optarg, &(params->max_tolerable_latency)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing Max Tolerable Latency '%s'.\n", optarg);
+				ret_errors++;
+			} else {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Max_tolerable_latency %d\n",
+						params->max_tolerable_latency);
+			}
 		    break;
 
 		case 'T':
-		    params->timeoutrecv = atoi(optarg);
-		    nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Time-out receiving %d\n",
-			    params->timeoutrecv);
+			if(nmxptool_parse_int(optarg, &(params->timeoutrecv)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing Time-out receving '%s'.\n", optarg);
+				ret_errors++;
+			} else {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Time-out receiving %d\n",
+						params->timeoutrecv);
+			}
 		    break;
 
 		case 'v':
-		    params->verbose_level = atoi(optarg);
+			if(nmxptool_parse_int(optarg, &(params->verbose_level)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing verbose level '%s'.\n", optarg);
+				ret_errors++;
+			}
 		    break;
 
 		case 'B':
@@ -868,13 +929,16 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 		    break;
 
 		case 'A':
-		    if(optarg) {
-			params->max_data_to_retrieve = atoi(optarg);
-		    }
+			if(optarg) {
+				if(nmxptool_parse_int(optarg, &(params->max_data_to_retrieve)) == 0) {
+					nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing Max amount of data to retrieve '%s'.\n", optarg);
+					ret_errors++;
+				}
+			}
 		    nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Max_time_to_retrieve %d\n", params->max_data_to_retrieve);
 		    break;
 
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
 		case 'k':
 		    params->flag_slink = 1;
 		    if(params->flag_slinkms) {
@@ -891,7 +955,7 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 #endif
 
 #ifdef HAVE_LIBMSEED
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
 		case 'K':
 		    params->flag_slinkms = 1;
 		    if(params->flag_slink) {
@@ -908,15 +972,21 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 #endif
 #endif
 
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
 		case 'Q':
-		    params->timing_quality = atoi(optarg);
+			if(nmxptool_parse_int(optarg, &(params->timing_quality)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing timing quality '%s'.\n", optarg);
+				ret_errors++;
+			}
 		    break;
 #endif
 
 #ifndef HAVE_WINDOWS_H
 		case 'E':
-		    params->listen_port = atoi(optarg);
+			if(nmxptool_parse_int(optarg, &(params->listen_port)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing listen port '%s'.\n", optarg);
+				ret_errors++;
+			}
 		    break;
 #endif
 
@@ -1038,25 +1108,29 @@ int nmxptool_getopt_long(int argc, char **argv, NMXPTOOL_PARAMS *params)
 		    break;
 
 		case 'r':
-		    params->reclen = atoi(optarg);
-		    if(params->reclen >= DEFAULT_RECLEN_MINIMUM  &&  params->reclen <= DEFAULT_RECLEN_MAXIMUM) {
-			flag_reclen_pow = 0;
-			while(!flag_reclen_pow  &&  reclen_pow <= DEFAULT_RECLEN_MAXIMUM) {
-			    if(params->reclen == reclen_pow) {
-				flag_reclen_pow = 1;
-			    }
-			    reclen_pow *= 2;
+			if(nmxptool_parse_int(optarg, &(params->reclen)) == 0) {
+				nmxp_log(NMXP_LOG_NORM, NMXP_LOG_D_ANY, "Error parsing mini-SEED record length '%s'.\n", optarg);
+				ret_errors++;
+			} else {
+				if(params->reclen >= DEFAULT_RECLEN_MINIMUM  &&  params->reclen <= DEFAULT_RECLEN_MAXIMUM) {
+					flag_reclen_pow = 0;
+					while(!flag_reclen_pow  &&  reclen_pow <= DEFAULT_RECLEN_MAXIMUM) {
+						if(params->reclen == reclen_pow) {
+							flag_reclen_pow = 1;
+						}
+						reclen_pow *= 2;
+					}
+					if(!flag_reclen_pow) {
+						ret_errors++;
+						nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY,
+								"reclen must expressible as 2 raised to the power of X where X is between (and including) 8 to 20.\n");
+					}
+				} else {
+					ret_errors++;
+					nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY,
+							"reclen must expressible as 2 raised to the power of X where X is between (and including) 8 to 20.\n");
+				}
 			}
-			if(!flag_reclen_pow) {
-			    ret_errors++;
-			    nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY,
-				    "reclen must expressible as 2 raised to the power of X where X is between (and including) 8 to 20.\n");
-			}
-		    } else {
-			ret_errors++;
-			nmxp_log(NMXP_LOG_NORM_NO, NMXP_LOG_D_ANY,
-				"reclen must expressible as 2 raised to the power of X where X is between (and including) 8 to 20.\n");
-		    }
 		    break;
 #endif
 
@@ -1339,7 +1413,7 @@ int nmxptool_check_params(NMXPTOOL_PARAMS *params) {
 	nmxp_log(NMXP_LOG_WARN, NMXP_LOG_D_ANY, "<timeoutrecv> ignored since not defined --stc=-1.\n");
     }
 
-#ifdef HAVE___SRC_SEEDLINK_PLUGIN_C
+#ifdef HAVE_SEEDLINK
     if( params->timing_quality != DEFAULT_TIMING_QUALITY &&
 	    ( params->timing_quality < DEFAULT_TIMING_QUALITY_MINIMUM ||  params->timing_quality > DEFAULT_TIMING_QUALITY_MAXIMUM) ) {
 	ret = -1;
