@@ -120,10 +120,10 @@ int main( int argc, char *argv[] )
 {
   TYPE_GETUTIL_INFO getutil_info;
 
-  unsigned     tidMessagePrinter;                 /* Thread read message from queue and populate DB */
+  ew_thread_t     tidMessagePrinter;                 /* Thread read message from queue and populate DB */
   TYPE_ARGS_PRINTER args_printer;
 
-  unsigned     tidStacker[MAX_NUM_OF_RINGS];                    /* Thread moving messages from transport to queue */
+  ew_thread_t     tidStacker[MAX_NUM_OF_RINGS];                    /* Thread moving messages from transport to queue */
   TYPE_ARGS_STACKER args_stacker[MAX_NUM_OF_RINGS];
   int          r = 0;
   int          nRings = 0;
