@@ -10,7 +10,7 @@
 /************************************************************************/
 
 /*
- * Copyright (c) 1996-2011 The Regents of the University of California.
+ * Copyright (c) 1996-2018 The Regents of the University of California.
  * All Rights Reserved.
  * 
  * Permission to use, copy, modify, and distribute this software and its
@@ -37,13 +37,8 @@
  * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
  */
 
-#ifndef lint
-static const char sccsid[] = "$Id: ms_utils.c 6803 2016-09-09 06:06:39Z et $ ";
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
-#include <memory.h>
 #include <string.h>
 #include <math.h>
 
@@ -301,7 +296,7 @@ int read_ms_bkt
     int		offset, i, bl_limit;
     SEED_UWORD	bl_len, bl_next, bl_type;
     int		bh_len = sizeof(BLOCKETTE_HDR);
-    int		blksize = 0;
+    int		blksize;
     int		preread = 0;    /* # bytes of blockette data preread.	*/
 
     if (my_wordorder < 0) get_my_wordorder();
@@ -436,6 +431,7 @@ int read_ms_bkt
 	bs->wordorder = hdr->hdr_wordorder;
 	if (bl_type == 1000) {
 	    blksize = (int)pow(2., (double)((BLOCKETTE_1000 *)(buf+offset))->data_rec_len);
+	    if (blksize <= 0) fprintf (stderr, "Warning: invalid blksize in blockette 1000\n");
 	}
 	offset += bl_len;
 	preread = 0;
@@ -464,7 +460,6 @@ int read_ms_data
 {
     BS *bs;			/* ptr to blockette structure.		*/
     BLOCKETTE_1000 *b1000;	/* ptr to blockette 1000.		*/
-    int format;
     int blksize;
     int datasize;
 
@@ -474,7 +469,6 @@ int read_ms_data
 	return (MS_ERROR);
     }
     b1000 = (BLOCKETTE_1000 *)bs->pb;
-    format = b1000->format;
     blksize = (int)pow (2., (double)b1000->data_rec_len);
     datasize = (hdr->first_data > 0) ? blksize - hdr->first_data : 0;
 
