@@ -1,4 +1,3 @@
-
 /* 0.0.26 2014-09-30 - made report interval a float */
 /* 0.0.27 2014-11-21 - added frac sec to origin time in CSV output*/
 /* 0.0.28 2015-01-07 - saved memory for large catalogs of 50K quakes by freeing mag aux struct */
@@ -7,26 +6,25 @@
 #define VERSION_STR "0.0.29.1 - 2015-11-06"
 
 
-
 /* Includes
  **********/
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
 #include <time.h>
-
-#include <earthworm.h>
-#include <transport.h>
-#include <kom.h>
-#include <read_arc.h>
-#include <rw_mag.h>
-#include <site.h>
-#include <chron3.h>
 #ifndef _WINNT
 #include <unistd.h>
 #endif
 
+#include "earthworm.h"
+#include "transport.h"
+#include "kom.h"
+#include "read_arc.h"
+#include "rw_mag.h"
+#include "site.h"
+#include "chron3.h"
+
 #include "ewjson.h"
 #include "arc2csv.h"
 //#include "webdata.h"
@@ -48,10 +46,6 @@
 #define DEFAULT_HTMLBASE "./ewhtmlreport.html"
 
 
-
-
-
-
 /* Functions in this file
  ************************/
 void PrintErrorMsg( void );
@@ -64,7 +58,6 @@ void sendEmailToAll(char *, char *, time_t , time_t , int );
 void MyCopyFile(char *from, char *to);
 
 
-
 /* Externals - Removed to allow compilation without objcopy
  ***********/
 /*
@@ -118,7 +111,6 @@ static char       SubjectPrefix[MAX_STRING_SIZE];     // defaults to EWalert, se
 static char          MinQuality = MIN_QUALITY_FLAG;	// minimum quality flag to allow into report
 
 
-
 /* Things to look up in the earthworm.h tables with getutil.c functions
  **********************************************************************/
 static long               InRingKey;       // key of transport ring for input
@@ -133,6 +125,7 @@ static time_t		timeLastBeat;		/* time last heartbeat was sent */
 
 #define MAX_QUAKES 	100	// should make this configurable at some point
 
+
 /* Main program starts here
  **************************/
 int main(int argc, char **argv) 
@@ -1016,7 +1009,7 @@ int ScanArcFolder( FILE *output, FILE *csv_output, time_t MinTime, time_t MaxTim
 						* MAX_MAG_CHANS ) ) )
 				{
 					if( !Standalone ) logit( "et",
-							"ewhtmlreport: failed to allocate %d bytes"
+							"ewhtmlreport: failed to allocate %zu bytes"
 							" for ML buffer; exiting!\n", 
 							sizeof(MAG_CHAN_INFO)*MAX_MAG_CHANS  );
 					free( fbuffer );
