@@ -5,7 +5,7 @@
 #include <time.h>
 #include <windows.h>
 
-void log( char *, char *, ... );
+void log_msg( char *, char *, ... );
 
 
    /*************************************************************************
@@ -25,7 +25,7 @@ void TzSet( char *tz )
 
    if ( _putenv( envstring ) == -1 )
    {
-      log( "et", "Error: Can't set environmental variable TZ. Exiting.\n" );
+      log_msg( "et", "Error: Can't set environmental variable TZ. Exiting.\n" );
       exit( -1 );
    }
    _tzset();
